#
# spec file for package logstalgia
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           logstalgia
Version:        1.1.4
Release:        1.12
Summary:        A website access log visualization tool
License:        GPL-3.0-or-later
Group:          Amusements/Toys/Other
URL:            https://logstalgia.io/
Source:         https://github.com/acaudwell/Logstalgia/releases/download/logstalgia-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  Mesa-libGLU-devel
BuildRequires:  ftgl-devel
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  glm-devel >= 0.9.3
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(SDL2_image) >= 2.0
BuildRequires:  pkgconfig(freetype2) >= 9.0.3
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libpng) >= 1.2
BuildRequires:  pkgconfig(sdl2) >= 2.0
Requires:       freefont
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel >= 1.46
BuildRequires:  libboost_headers-devel >= 1.46
BuildRequires:  libboost_system-devel >= 1.46
%else
BuildRequires:  boost-devel >= 1.46
%endif

%description
Logstalgia is a website traffic visualization that replays or streams
Apache web-server access logs as a pong-like battle between the web
server and an never ending torrent of requests. Requests appear as
colored balls (the same color as the host) which travel across the
screen to arrive at the requested location. Successful requests are
hit by the paddle while unsuccessful ones (eg 404 - File Not Found)
are missed and pass through.

%prep
%setup -q

%build
%configure \
  --enable-ttf-font-dir=%{_datadir}/fonts/truetype
%make_build

%install
%make_install

%files
%license COPYING
%doc README THANKS ChangeLog
%{_mandir}/man1/logstalgia*
%{_bindir}/logstalgia
%{_datadir}/logstalgia/

%changelog
* Mon Jan 30 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.4:
  * Added experimental support for Wayland (beroset).
  * Updated autoconf macros.
  * Fixed INSTALL instructions regarding GLM.
* Fri Dec  9 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.3:
  * Added --high-dpi option.
  * Support rendering at native resolution on Retina / Ultra HD displays.
  * Change regular expression library to PCRE2.
  * Added Boost Filesystem build requirement.
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1.2:
  * Fixed compatibility with GLM 0.9.9.0.
  * Fixed rendering of FreeMonoBold with FreeType2 2.8 by disabling hinting.
  * Updated fonts.
* Fri Nov 17 2017 astieger@suse.com
- logstalgia 1.0.9:
  * Fix config change not being detected in some cases
- includes changes from 1.0.8:
  * Performance improvements
  * Change unsuccessful response code direction to match ball
  * Add --screen option
  * Add --window-position XxY option
  * Add --frameless option
  * Add --title option (mclang)
  * Add --detect-changes option to automatically reload config file
  * Add --display-fields FIELDS to set fields shown mousing over a request
  * Can now specify path separators, max path depth and min abbreviation depth
  * Reload config (F5)
  * Save config (Ctrl+S) with updated display settings
  * Fix queued log entries not being deleted when seeking using the timeline
  * Make --hide-url-prefix apply to https URLs
  * Counter no longer overflows at 100000000.
  * Now requires SDL 2 to build (deprecated SDL 1.2 support removed)
* Sat Jul 15 2017 astieger@suse.com
- logstalgia 1.0.7:
  * Added window frame toggle (F11).
  * Fixed crash when taking a screenshot with an odd resolution.
  * Handle exception when user defined regular expression is invalid.
  * Fixed --hide-url-prefix not working
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 27 2014 andreas.stieger@gmx.de
- Licence is GPL-3.0+
* Wed Nov 26 2014 andreas.stieger@gmx.de
- logstalgia 1.0.6
  + Display invalid requests as having the path '???'.
- includes changes from 1.0.5:
  + Performance improvements.
  + Multi-monitor support using SDL 2.0.
  + Can now specify the attribute to match the group regex (-g)
    against.
  + When using --sync, now catches back up after resuming from pause.
  + Added --pitch-speed option (control how fast balls travel).
  + Made default group matches case-insensitive
  + Display tokens in multi-paddle modes
  + Added window resizing and a full-screen toggle (alt-enter).
  + Take screenshots (F12).
  + Summarizer component content is now sorted.
  + IPv6 addresses now anonymized by default as well (last 64 bits).
  + New dependencies on libpng, GLEW.
  + Now requires GLM and Boost header-only libraries to build.
- includes changes from 1.0.4:
  + Changed type of log entry timestamp to time_t.
  + Stopped directly linking PNG/JPG libraries.
- drop logstalgia-1.0.0-nonvoid.patch
- reformat spec file to current standard
- update dependencies
- update source URL
* Mon May 30 2011 prusnak@opensuse.org
- updated to 1.0.3
* Fri Nov 26 2010 prusnak@opensuse.org
- cleanup spec file
- use system-wide freefont
* Sat Oct  2 2010 xnull@opensuse.org
- initial release, version 1.0.0
